@@ -8,7 +8,7 @@
 #include "IMG/imgdata.h"
 #include "IMG/gmapdata.h"
 #include "IMG/rastertile.h"
-#include "IMG/dem.h"
+#include "IMG/demtree.h"
 #include "osm.h"
 #include "pcs.h"
 #include "rectd.h"
@@ -18,6 +18,7 @@ using namespace IMG;
 
 #define EPSILON     1e-6
 #define TILE_SIZE   384
+#define DELTA       1e-3
 
 static RectC limitBounds(const RectC &bounds, const Projection &proj)
 {
@@ -269,18 +270,18 @@ void IMGMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 
 double IMGMap::elevation(const Coordinates &c)
 {
-	QList<MapData::Elevation> tiles;
-	DEM::DEMTRee tree;
 	MapData *d = _data.first();
-	double ele = NAN;
 
-	d->elevations(RectC(Coordinates(c), Coordinates(c)), d->zooms().max(),
-	  &tiles);
+	if (d->hasDEM()) {
+		QList<MapData::Elevation> tiles;
 
-	DEM::buildTree(tiles, tree);
-	DEM::searchTree(tree, c, ele);
+		d->elevations(RectC(c, Coordinates(c.lon() + DELTA, c.lat() - DELTA)),
+		  d->zooms().max(), &tiles);
+		DEMTree tree(tiles);
 
-	return ele;
+		return tree.elevation(c);
+	} else
+		return Map::elevation(c);
 }
 
 Map* IMGMap::createIMG(const QString &path, const Projection &proj, bool *isDir)
